deepint.core
================

.. automodule:: deepint.core
   :special-members:
   :exclude-members:
   :members:

.. toctree::
   :maxdepth: 3

   ./core/organization.rst
   ./core/workspace.rst
   ./core/source.rst
   ./core/model.rst
   ./core/task.rst
   ./core/alert.rst